; 3-state reversible Michaelis-Menten enzyme kinetics with E, ES, and EP conformations.
; initial rate constants are for the Lac-1-beta-lactamase.
;
; The results for ticks = 0 are identical to Table 3 values from Juretić-2019-lactamases
; if all concentratins are in micromoles.
; RT (thermale) was set to the value 1
; for easier comparison with Juretić-2019 results.
;.
;
; the ES and EP complex is introduced instead of "complex"
; rate constants and concentrations are from Juretić-2019 and Christensen-1990
; for B. cereus Lac-1 beta-lactamase.
;
; K(M) and k(cat)/K(M) are in moles

breed [ enzymes enzyme]      ;; red turtles that bind with and catalyze substrate
breed [ substrates substrate ]   ;; green turtles that bind with enzyme
breed [ products product ]     ;; blue turtle generated from enzyme catalysis
breed [ESenzymes ESenzyme]
breed [EPenzymes EPenzyme]


turtles-own [
;
  partner   ;; holds the turtle this turtle is complexed with,
               ;; or nobody if not complexed
]

globals [
  substrate-added ;; keeps track of how much substrate has been added
  v               ;; rate of complex formation at each time step
  substrates-init
  products-init
  enzymes-init
  k1
  k1exp
  k1*
  k1*var
  k2
  k3
  k4
  k4var
  k5
  k6
  k6*
  k6*var
  k2exp
  k3exp
  k4exp
  k5exp
  k6var
  k6exp
  Keq2
  Keq3*
  Keq1*
  Keq1
  Keq3
  Kneq1
  Kneq2
  Kneq3
  k3var
  KeqTOT
  KneqTOT
  CEtot
  CSPtot
  Efree
  Sfree
  Pfree
  GAMA
  FORCE
  kcat
  enzeff
  kcatrev
  enzeffrev
  Km
  Kmrev
  p1N
  p1
  p2N
  p2
  p3N
  p3
  pallD
  currB1
  currB2
  currB3
  aX1
  aX2
  aX3
  aXtot
  Xsec
  dissB1
  dissB2
  dissB3
  dissTOT
  entropy
  s1
  s2
  gaussrand
  gaussrand2
  gaussrand3
  gaussrand4
  gaussrand5
  gaussrand6
]
extensions [ csv ]
;
to setup
    clear-all
;  if file-at-end? [ stop ]
  file-close-all
;  file-open "myFile.csv"
  clear-turtles
  set substrate-added 0
  set kcat 0
;
  set substrate-added 0
  set v 0
  add enzymes 10                   ;; starts with constant number of enzymes (in microM)
;
  set enzymes-init 10
  add substrates 1285             ;; add substrates to enzymes (microM)
  add products 215                  ;; add products to enzymes (microM)
;
  set substrates-init 1285
  set products-init 215
;
  clear-all-plots
  reset-ticks
end

;; observer procedure to add molecules to reaction
to add [kind amount]
  create-turtles amount
    [ set breed kind
      setxy random-xcor random-ycor
      set partner nobody
;
      setshape ]
  if kind = substrates
    [ set substrate-added substrate-added + amount ]
end

;; procedure that assigns a specific shape to a turtle, and shows
;; or hides it, depending on its state
to setshape
  if breed = enzymes
    [ set color red
      ifelse partner = nobody
        [ set shape "enzyme" ]
        [ if ([breed] of (partner) = substrates)
        [ set shape "ESenzyme" ]]
      ifelse partner = nobody
      [ set shape "enzyme" ]
        [if ([breed] of (partner) = products)
        [ set shape "EPenzyme" ]]]
;
     if breed = substrates
        [ set color green
        set shape "substrate"]
;
       ifelse breed = products
        [ set color blue
      set shape "substrate"]
;
            [ if breed = products
                [ set color blue
                  set shape "substrate"
;
            set hidden? false ] ]
end

;; main procedure
to go
;
    if (ticks = 2200)
    [ stop ]
  ask turtles [ move ]                ;; only non-complexed turtles will move
  ask enzymes [ form-EScomplex ]         ;; enzyme may form complexes with substrate
;
  ask enzymes [ form-EPcomplex ]     ;; enzyme may form complex with product
;
  ask EPenzymes [ react-forward ]     ;; EPcomplex may turn into product and free enzyme
;
  ask ESenzymes [ dissociate ]           ;; EScomplex may just split apart
  ask ESenzymes [form-EP-from-ES]
  ask EPenzymes [form-ES-from-EP]
  calculate-velocity
  calculate-performance
  if ticks < 1
    [ file-open "S21-RTEM-exper-performance.txt"
      file-print ("ticks")
      file-show ticks
      file-print ("dissTOT")
      file-show dissTOT
      file-print ("dissB1")
      file-show dissB1
      file-print ("dissB2")
      file-show dissB2
      file-print ("dissB3")
      file-show dissB3
      file-print ("kcat")
      file-show kcat
      file-print ("K(M)")
      file-show Km
      file-print ("eff")
      file-show enzeff
      file-print ("J1")
      file-show currB1
       file-print ("J2")
      file-show currB2
       file-print ("J3")
      file-show currB3
      file-print ("Keq1*")
      file-show Keq1*
 ;     file-show Keq2*
      file-print ("Keq2")
      file-show Keq2
      file-print ("Keq3*")
      file-show Keq3*
      file-print ("Kneq1")
      file-show Kneq1
      file-print ("Kneq2")
      file-show Kneq2
      file-print ("Kneq3")
      file-show Kneq3
      file-print ("Xtot")
      file-show FORCE
      file-print ("xsec")
      file-show xsec
      file-print ("X1")
      file-show aX1
      file-print ("X2")
      file-show aX2
      file-print ("X3")
      file-show aX3
      file-print ("entropy")
      file-show entropy
      file-print ("products#")
      file-show products-init
      file-print ("substrates#")
      file-show substrates-init
      file-print ("Ktot")
      file-show KeqTOT
      file-print ("GAMA")
      file-show GAMA
      file-print ("k1exp microM")
      file-show k1exp
      file-print ("k2exp")
      file-show k2exp
      file-print ("k3exp")
      file-show k3exp
      file-print ("k4exp")
      file-show k4exp
      file-print ("k5exp")
      file-show k5exp
      file-print ("k6exp")
      file-show k6exp
      file-print ("p1")
      file-show p1
      file-print ("p2")
      file-show p2
      file-print ("p3")
      file-show p3
        file-print ("........")
        file-close ]
;
             if ticks >= 0
;    data output into the CSV file with 43 columns easily converted into xlsx file
;
     [ file-open "S21-RTEM.csv"
    if ticks < 1
    [file-print csv:to-row ["tick"
      "X"
      "Ptot"
      "Eff"
      "P1"
      "P2"
      "P3"
      "p1"
      "p2"
      "p3"
      "K1"
      "K2"
      "K3"
      "k1"
      "k2"
      "k3"
      "k4"
      "k5"
      "k6"
      "X1"
      "X2"
      "X3"
      "S(I)"
      "Km"
      "Etot"
      "SPtot"
      "Efree"
      "Sfree"
      "Pfree"
      "ES"
      "EP"
      "J"
      "kcat"
      "kcatrev"
      "Kmrev"
      "Effrev"
      "Xsec"
      "FORCE"
      "Keq1"
      "Keq2"
      "Keq2"
      "Ktot"
;
    ]]
;
     if ticks >= 0
    [
           file-print csv:to-row (list ticks aXtot dissTOT enzeff dissB1 dissB2 dissB3 p1 p2 p3
           Kneq1 Kneq2 Kneq3 k1 k2 k3 k4 k5 k6 aX1 aX2 aX3 entropy Km CEtot CSPtot Efree Sfree Pfree
        count ESenzymes count EPenzymes currB1 kcat kcatrev Kmrev enzeffrev Xsec FORCE Kneq1 Kneq2 Kneq3 KneqTOT)
;
    file-close ]]
;
  tick
end

to move  ;; turtle procedure
  if partner = nobody
    [ fd 1
      rt random-float 360 ]
;
end

;
to form-EScomplex  ;; enzyme procedure
;
  if partner != nobody [ stop ]
  if partner = nobody and Efree > 0
   [set partner one-of (other substrates-here with [partner = nobody])
;
      if (any? other substrates-here) and random-float 1000 < k1
;
     [ ask enzymes-here
      [ setshape
      set breed ESenzymes
          set shape "ESenzyme" ]
;
        set partner nobody ] ]
;
  ask enzymes-here
     [ setshape
      set breed ESenzymes
      set shape "ESenzyme" ]
;
end
;
to form-EPcomplex
;
  if count ESenzymes > 0
  [if (any? other ESenzymes-here) and random-float 10 < k3
;
    [ set breed EPenzymes
      set shape "EPenzyme" ]]
end
;; substrate procedure that controls the rate at which complexed substrates
;; are converted into products and released from the complex
to react-forward
;
  if count EPenzymes > 0
  [ if (any? other EPenzymes-here) and random-float 10 < k5
    [ set breed products
      set shape "substrate"
;
    ask EPenzymes-here
     [ set breed enzymes
        set shape "enzyme" ] ] ]
end

;; enzyme procedure that controls the rate at which complexed turtles break apart
to dissociate
  if count ESenzymes > 0
   [ if partner != nobody
    [ if ([breed] of partner = substrates) and (random-float 100 < k2)
;
       [ ask partner [ set partner nobody ]
        let old-partner partner
        set partner nobody
          set breed substrates
          set shape "substrate"
;
   ask ESenzymes-here
     [ set breed enzymes
            set shape "enzyme"]
;
          ask old-partner [setshape]]]]
end

to form-EP-from-ES
  if count ESenzymes > 0
   [if (any? other ESenzymes-here) and
     random-float 10 < k3
     [ set breed EPenzymes
        set shape "EPenzyme" ]]
end

to form-ES-from-EP
  if count EPenzymes > 0
  [if (any? other EPenzymes-here) and
     random-float 10 < k4
     [ set breed ESenzymes
      set shape "ESenzyme" ]]
end
;
;
to calculate-performance
; all concentrations in microM
   if ticks < 1
;
  [set k1* 41 * 1000000.0
    set k2 2320.0
    set k3 4090.0
    set k4 50.0
    set k5 3610.0
    set k6* 8 * 1000000.0
 ;
    set k1 k1* * substrates-init / 1000000.0
 ;
     set k6 k6* * products-init / 1000000.0
;
    set Keq2 k3 / k4
    set Keq1* k1* / k2
    set Keq3* k5 / k6*
    set Kneq1 k1 / k2
    set Kneq2 k3 / k4
    set Kneq3 k5 / k6
    set KeqTOT Keq1* * Keq2 * Keq3*
    set KneqTOT Kneq1 * Kneq2 * Kneq3
;
    set Efree enzymes-init - count ESenzymes - count EPenzymes
    set Pfree count products with [partner = nobody]
    set Sfree substrates-init + products-init - count ESenzymes - count EPenzymes
        - Pfree
    set CEtot Efree + count ESenzymes + count EPenzymes
    set CSPtot substrates-init + products-init
    set GAMA (count products with [partner = nobody]) /
     Sfree
;
    set FORCE  (- ln ( GAMA / KeqTOT))
;
    set kcat ( k3 * k5 ) / ( k3 + k5 + k4 )
;
    set kcatrev ( k2 + k4 ) / ( k2 + k4 + k3 )
;
    set Km ( k3 * k5 + k2 * k5 + k2 * k4 ) /
    ( k1* * ( k3 + k5 + k4 ) )
;
     set enzeff kcat / Km
;
    set Kmrev ( k3 * k5 + k2 * k5 + k2 * k4 ) /
    ( k6* * ( k3 + k2 + k4 ) )
    set enzeffrev kcatrev / Kmrev
;
    set p1N k4 * k2 + k3 * k5 + k2 * k5
    set p2N k1 * k4 + k6 * k4 + k5 * k1
    set p3N k1 * k3 + k6 * k3 + k2 * k6
      set pallD p1N + p2N + p3N
      set p1 p1N / pallD
      set p2 p2N / pallD
      set p3 p3N / pallD
       set currB1 k1 * p1 - k2 * p2
       set currB2 k3 * p2 - k4 * p3
       set currB3 k5 * p3 - k6 * p1
 ;
       set Xsec ln (( k1 * k3 * k5 ) /
       ( k2 * k4 * k6 ))
       set aX1 ln (( k1 * p1 ) / ( k2 * p2 ))
       set aX2 ln (( k3 * p2 ) / ( k4 * p3 ))
       set aX3 ln (( k5 * p3 ) / ( k6 * p1 ))
 ;
       set aXtot aX1 + aX2 + aX3; should be identical to xsec
         set dissB1 aX1 * currB1
         set dissB2 aX2 * currB2
         set dissB3 aX3 * currB3
  ;
         set dissTOT dissB1 + dissB2 + dissB3
 ;
     set entropy (( p1 * ln p1 + p2 * ln p2 + p3 * ln p3 ) * (-1))
  ]
; performance after random values for rate constants
; with the same equlibrium constants
   if ticks > 0
;
   [
    set Efree enzymes-init - count ESenzymes - count EPenzymes
    set Pfree count products with [partner = nobody]
    set Sfree substrates-init + products-init - count ESenzymes - count EPenzymes
        - Pfree
    set CEtot Efree + count ESenzymes + count EPenzymes
    set CSPtot Sfree + Pfree + count ESenzymes + count EPenzymes
;
    set k1* 41 * 1000000.0
    set k2exp 2320.0
    set k3exp 4090.0
    set k4exp 50.0
    set k5exp 3610.0
    set k6* 8 * 1000000.0
    let thermale 2.4361
;
      set s1 1.0
;
      set s2 1.0
;
;
      set  gaussrand sqrt(-2 * ln (random-float s1)) * cos (2 * pi * random-float s2)
;
      set  gaussrand2 sqrt(-2 * ln (random-float s1)) * cos (2 * pi * random-float s2)
;
      set  gaussrand3 sqrt(-2 * ln (random-float s1)) * cos (2 * pi * random-float s2)
;
      set  gaussrand4 sqrt(-2 * ln (random-float s1)) * cos (2 * pi * random-float s2)
;
      set  gaussrand5 sqrt(-2 * ln (random-float s1)) * cos (2 * pi * random-float s2)
;
      set  gaussrand6 sqrt(-2 * ln (random-float s1)) * cos (2 * pi * random-float s2)
;
      set k1*var 41 * 1000000.0
;
     set k1 k1*var * Sfree / 1000000.0
      set Keq1* k1* / k2exp
      set Keq1 Keq1* * Sfree / 1000000.0
;
     set k2 2320.0
;
      set Kneq1 k1 / k2
;
      set Keq2 k3exp / k4exp
;
      set k4var 50.0 * gaussrand4
;
      set k4 k4var
;
      set k3var 4090 * gaussrand3
      set k3 k3var
;
      set Kneq2 k3 / k4
;
      set k6*var 8.0 * 1000000.0
      set k6 k6*var * Pfree / 1000000.0
      set Keq3* k5exp / k6*
;
      set Keq3 Keq3* / Pfree / 1000000.0
;
      set k5 3610.0
;
      set Kneq3 k5 / k6
;
    set KeqTOT Keq1* * Keq2 * Keq3*
    set KneqTOT Kneq1 * Kneq2 * Kneq3
;
      set GAMA Pfree / Sfree
    set FORCE ( - ln ( GAMA / KeqTOT))
 ;
     set kcat ( k3 * k5 ) / ( k3 + k5 + k4 )
;
    set kcatrev ( k2 + k4 ) / ( k2 + k4 + k3 )
;
    set Km ( k3 * k5 + k2 * k5 + k2 * k4 ) / ( k1*var * ( k3 + k5 + k4 ) )
     set enzeff kcat / Km
;
    set Kmrev ( k3 * k5 + k2 * k5 + k2 * k4 ) / ( k6*var * ( k3 + k2 + k4 ) )
    set enzeffrev kcatrev / Kmrev
 ;
     set p1N k4 * k2 + k3 * k5 + k2 * k5
     set p2N k1 * k4 + k6 * k4 + k5 * k1
     set p3N k1 * k3 + k6 * k3 + k2 * k6
      set pallD p1N + p2N + p3N
      set p1 p1N / pallD
      set p2 p2N / pallD
      set p3 p3N / pallD
       set currB1 k1 * p1 - k2 * p2
       set currB2 k3 * p2 - k4 * p3
       set currB3 k5 * p3 - k6 * p1
       set Xsec ln (( k1 * k3 * k5 ) / ( k2 * k4 * k6 ))
       set aX1 ln (( k1 * p1 ) / ( k2 * p2 ))
      set aX2 ln (( k3 * p2 ) / ( k4 * p3 ))
      set aX3 ln (( k5 * p3 ) / ( k6 * p1 ))
       set aXtot aX1 + aX2 + aX3; should be identical to xsec
         set dissB1 aX1 * currB1
         set dissB2 aX2 * currB2
         set dissB3 aX3 * currB3
         set dissTOT dissB1 + dissB2 + dissB3
     set entropy (( p1 * ln p1 + p2 * ln p2 + p3 * ln p3 ) * (-1))
 ]
end
to calculate-velocity
  let initial-conc substrate-added
  let current-conc count substrates with [partner = nobody]
  if ticks > 0
    [ set v (initial-conc - current-conc) / ticks ]
end

;
;
;  Author: Davor Juretic, year:2023, preprint:
;  Computational Improvements of Enzyme Efficiency kcat/KM by Increasing Noise and Dissipation
;  Submitted to the Entropy journal in January 2024 with the title:
;  Theoretical Improvements in Enzyme Efficiency Associated with Noisy Rate Constants and Increased Dissipation
;
;  Inspired by Uri Wilensky "Enzyme Kinetics" in 2001
;  Our NetLogo source code is based on the simulation „Enzyme Kinetics“
;  (Stieff and Wilensky: https://ccl.northwestern.edu/netlogo/models/EnzymeKinetics)
;  of the traditional Michaelis-Menten model for reversible E+S↔ES transition and irreversible complex dissociation ES→E+P.
;  We extended it to all reversible transitions among 3
;  functionally important RTEM beta-lactamase conformational states.
;  Independent variations of rate constants k3 and k4
@#$#@#$#@
GRAPHICS-WINDOW
289
10
647
369
-1
-1
14.0
1
10
1
1
1
0
1
1
1
-12
12
-12
12
1
1
1
ticks
30.0

BUTTON
4
41
68
74
setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
69
41
130
74
go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
0

MONITOR
289
393
355
438
Velocity
v
3
1
11

PLOT
3
181
287
359
Concentrations
time
C
0.0
50.0
0.0
50.0
true
true
"" ""
PENS
"ES-complex" 1.0 0 -16777216 true "" "plot count ESenzymes"
"Product" 1.0 0 -13345367 true "" "plot Pfree "
"Enzyme" 1.0 0 -2674135 true "" "plot Efree / 10"
"Substrate" 1.0 0 -10899396 true "" "plot Sfree / 100"
"EP-complex" 1.0 0 -5825686 true "" "plot count EPenzymes"

SWITCH
289
444
390
477
pause?
pause?
1
1
-1000

PLOT
424
379
624
529
Eff-Ptot
entropy production
enzyme efficiency
0.0
10.0
0.0
100.0
true
false
"" ""
PENS
"Eff-EP" 1.0 2 -16777216 true "" "plotxy dissTOT enzeff"

MONITOR
21
386
78
431
NIL
Sfree
17
1
11

MONITOR
108
384
165
429
NIL
Pfree
17
1
11

MONITOR
192
382
249
427
NIL
Efree
17
1
11

@#$#@#$#@
## WHAT IS IT?

This model demonstrates the kinetics of single-substrate enzyme-catalysis. The interactions between enzymes and substrates are often difficult to understand and the model allows users to visualize the complex reaction.

The standard equation for this reaction is shown below.

```text
                  Kc          Kr
        E + S <=======> E-S ------> E + P
                  Kd
```

Here E represents Enzyme, S Substrate, E-S Enzyme-Substrate complex, and P product.  The rate constants are Kc for complex formation, Kd for complex dissociation, Kr for catalysis.  The first step in catalysis is the formation of the E-S complex.  This can consist of either covalent or non-covalent bonding.  The rates of complex formation and dissociation are very fast because they are determined by collision and separation of the molecules.  The next step is for the enzyme to catalyze the conversion of substrate to product.  This rate is much slower because the energy required for catalysis is much higher than that required for collision or separation.

The model demonstrates several important properties of enzyme kinetics.  Enzyme catalysis is often assumed to be controlled by the rate of complex formation and dissociation, because it occurs much faster than the rate of catalysis. Thus, the reaction becomes dependent on the ratio of Kc / Kd.  The efficiency of catalysis can be studied by observing catalytic behavior at different substrate concentrations.

By measuring the rate of complex formation at different substrate concentrations, a Michaelis-Menten Curve can be plotted.  Analysis of the plot provides biochemists with the maximum rate (Vmax) at which the reaction can proceed. As can be seen from the model, this plot is linear at low levels of substrate, and non-linear at higher levels of substrate.  By examining the model, the reasons for this relationship can be seen easily.

Enzyme catalysis can also be controlled using inhibitors. Inhibitors are molecules that are structurally similar to substrate molecules that can complex with the enzyme and interfere with the E-S complex formation.  Subsequently, the shape of the Michaelis-Menten Curve will be altered. The model demonstrates the effects of inhibitors on catalysis.

## HOW TO USE IT

Choose the values of Kc, Kd, and Kr with appropriate sliders:
- Kc controls the rate at which substrates (green) and enzymes (red) stick together so that catalysis can occur
- Kd controls the rate at which they come unstuck
- Kr controls the rate of the forward reaction by which an enzyme (red) converts a substrate (green) to a product (blue)

Having chosen appropriate values of the constants, press SETUP to clear the world and create a constant initial number of enzyme (red) molecules. Play with several different values to observe variable effects on complex formation and catalysis.

Press GO to start the simulation.  A constant amount of enzyme (red) will be generated.  The concentrations of substrate, complex, and product are plotted in the CONCENTRATIONS window.

Experiment with using the ADD-SUBSTRATE and ADD-INHIBITOR buttons to observe the effects of adding more molecules to the system manually as it runs.  The default setting for Kr is 0, which means that no product (blue) will be generated unless you change Kr to a non-zero value.

Note that when complexes form they stop moving.  This isn't intended to be physically realistic; it just makes the formation of complexes easier to see.  (This shouldn't affect the overall behavior of the model.)

To plot the Michaelis-Menten Curve for your reaction conditions, you will have to perform several runs at different concentrations in order to measure the velocity for each run. To do this, set the PAUSE? switch ON.  When this switch is on, the model automatically stops after 30 time ticks.  Begin your assay by setting the substrate volume to zero and running the simulation.  When it stops, press RECORD V and a point will be plotted on the Michaelis-Menten Curve. Run another simulation with a higher concentration of substrate by changing the VOLUME slider, then hitting SETUP followed by GO, followed by RECORD V once the model stops.  Continue for several values of substrate concentrations until a curve is generated. If you wish to start over hit CLEAR MM to reset the plot.

## THINGS TO NOTICE

Watch the rate at which the enzyme and substrate stick together. How does this affect the conversion of substrate into product? What would happen if Kd is very high and Kc is very low? If Kr were the same order of magnitude as Kd and Kc?

Watch the Michaelis-Menten Curve. Does it match up with the discussion of enzyme kinetics discussed above? Why does the plot initially slope upward, then flatten out?

Which variables can alter the magnitude of v?

How does the magnitude of Kd and Kr affect the smoothness of the Michaelis-Menten Curve?

## THINGS TO TRY

Run the simulation with VOLUME set to various amounts. How does this affect the curve?

If Kr is MUCH greater than Kd, what affect does this have on the reaction?  How important does complex formation become in this situation?

If Kc is MUCH less than Kd, what does this mean in the real-world? How are the enzyme and substrate related under these conditions?

What effect does adding inhibitor to the model have on the plot? Is Vmax affected?

## EXTENDING THE MODEL

What would happen if yellow inhibitor molecules could react to form a product? How would this affect the plot?

Inhibitors can be irreversible or reversible. That is, they can bind to an enzyme and never let go, or they can stick and fall off. Currently, the model simulates irreversible inhibitors. Modify the code so that the yellow molecules reversibly bind to the enzyme. How does this affect catalysis?

Often, the product of catalysis is an inhibitor of the enzyme. This is called a feedback mechanism. In this model, product cannot complex with enzyme. Modify the procedures so that the product is a reversible inhibitor. How does this affect catalysis with and without yellow inhibitor?

Include a slider that allows you to change the concentration of enzyme.  What affect does this have on the plot?  Vmax?  Look closely!

## NETLOGO FEATURES

It is a little difficult to ensure that a reactant never participates in two reactions simultaneously.  In the future, a primitive called GRAB may be added to NetLogo; then the code in the FORM-COMPLEX procedure wouldn't need to be quite so tricky.

## CREDITS AND REFERENCES

Thanks to Mike Stieff for his work on this model.

## HOW TO CITE

If you mention this model or the NetLogo software in a publication, we ask that you include the citations below.

For the model itself:

* Stieff, M. and Wilensky, U. (2001).  NetLogo Enzyme Kinetics model.  http://ccl.northwestern.edu/netlogo/models/EnzymeKinetics.  Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

Please cite the NetLogo software as:

* Wilensky, U. (1999). NetLogo. http://ccl.northwestern.edu/netlogo/. Center for Connected Learning and Computer-Based Modeling, Northwestern University, Evanston, IL.

## COPYRIGHT AND LICENSE

Copyright 2001 Uri Wilensky.

![CC BY-NC-SA 3.0](http://ccl.northwestern.edu/images/creativecommons/byncsa.png)

This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 3.0 License.  To view a copy of this license, visit https://creativecommons.org/licenses/by-nc-sa/3.0/ or send a letter to Creative Commons, 559 Nathan Abbott Way, Stanford, California 94305, USA.

Commercial licenses are also available. To inquire about commercial licenses, please contact Uri Wilensky at uri@northwestern.edu.

This model was created as part of the projects: PARTICIPATORY SIMULATIONS: NETWORK-BASED DESIGN FOR SYSTEMS LEARNING IN CLASSROOMS and/or INTEGRATED SIMULATION AND MODELING ENVIRONMENT. The project gratefully acknowledges the support of the National Science Foundation (REPP & ROLE programs) -- grant numbers REC #9814682 and REC-0126227.

<!-- 2001 Cite: Stieff, M. -->
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

complex
true
15
Polygon -1184463 true false 76 47 197 150 76 254 257 255 257 47
Circle -13840069 true false 20 65 170

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

enzyme
true
15
Polygon -2674135 true false 76 47 197 150 76 254 257 255 257 47

epenzyme
true
0
Polygon -1184463 true false 76 47 197 150 76 254 257 255 257 47
Polygon -13791810 true false 77 48 198 151 78 253 0 253 0 46

esenzyme
true
15
Polygon -1184463 true false 76 47 197 150 76 254 257 255 257 47
Circle -13840069 true false 20 65 170

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

inhibitor
true
0
Polygon -1184463 true false 197 151 60 45 1 45 1 255 60 255

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

substrate
true
5
Polygon -10899396 true true 76 47 197 151 75 256

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270
@#$#@#$#@
NetLogo 6.3.0
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180
@#$#@#$#@
0
@#$#@#$#@
