       program     S7TPI
C
C Four-state-triosephosphate-enzyme-kinetic-scheme (TPI-enzyme)
C
C All rate constants are noisy. Negative rate constants are replaced with
C their observed values. There is no constraint of fixed equilibrium constants
C and fixed overall force.
C
       real*8  thermale,rckonst1,rckonst2,
     &   xsec,sigma,enprodB1,enprodB2,enprodB3,enprodB4,
     &   k12,k21,k23,k32,k34,k43,k41,k14,
     &   keqk12,keqk23,keqk34,keqk41,sigmap,sigmab,
     &   sigmah,sigmaq,currB1,currB2,currB3,currB4,
     &   keqk3,keqk1,keqk2,keqk4,enprodT,ckonst4a(10000),
     &   sprob(4),entros(4),entrops,aX1,aX2,aX3,aX4,aX,
     &   kcat,KMich,Ktot,ENZeff,substrates,ckonst1a(10000),
     &   s1,s2,pi,ckonst2a(10000),ckonst3a(10000),
     &   products,gaussrand1,gaussrand2,gaussrand3,
     &   gaussrand4,gaussrand5,gaussrand6,gaussrand7,gaussrand8
C
C
       keqk3=0.0
       keqk1=0.0
       keqk4=0.0
       keqk2=0.0
       keqk12=0.0
       keqk23=0.0
       keqk34=0.0
       keqk41=0.0
       aX1=0.0
       aX2=0.0
       aX3=0.0
       aX4=0.0
       aX=0.0
       enprodB3=0.0
       enprodB4=0.0
       enprodB1=0.0
       enprodB2=0.0
       sigmap=0.0
       sigmab=0.0
       sigmah=0.0
       sigmaq=0.0
C
       emprodB1=0.0
       emprodB2=0.0
       k12=0.0
       k21=0.0
       k23=0.0
       k32=0.0
       k34=0.0
       k43=0.0
       k41=0.0
       k14=0.0
       currB1=0.0
       currB2=0.0
       currB3=0.0
       currB4=0.0
       thermale=0.0
       xsec=0.0
       sigma=0.0
       kcat=0.0
       KMich=0.0
       ENZeff=0.0
       Ktot=0.0
       mmm=0
       i=0
       entrops=0.0
C
       s1=0.0
       s2=0.0
       pi=0.0
C       gaussrand=0.0
       gaussrand1=0.0
       gaussrand2=0.0
       gaussrand3=0.0
       gaussrand4=0.0
       gaussrand5=0.0
       gaussrand6=0.0
       gaussrand7=0.0
       gaussrand8=0.0
       nnn=0
       jjj=0
C
       do 25 nnn=1,10000
        ckonst4a(nnn)=0.0
        ckonst3a(nnn)=0.0
        ckonst2a(nnn)=0.0
        ckonst1a(nnn)=0.0
25     continue
C
       substrates=0.00004
       products=0.000000064
C      Kinetic constants k12 and k41 without [S] and [P] are from Gerlt-2021 (Figure 3)
C      in agreement with ZBL-Jureti-2017. It is all from
C       Knowles, J. R., and Albery, W. J. (1977) Perfection in enzyme catalysis:
C       the energetics of triosephosphate isomerase, Accounts of chemical research 10, 105111.
       k12=10000000.0*substrates
C       k12=400.0
       k21=7000.0
       k23=2000.0
       k32=6000.0
       k34=60000.0
       k43=90000.0
       k41=4000.0
C       k14=25.6
       k14=400000000*products
       keqk12=0.0571
       keqk23=0.3333
       keqk34=0.6667
       keqk41=156.25
       Ktot=keqk12*keqk23*keqk34*keqk41
C
C in moles
C
           thermale=2.4361
C RT in kJ/mol for 20 C
         pi=3.141592653589793

C
        open (unit=9,status='unknown',file='S7TPI-allrand-ki.dat',
     & access='sequential',form='formatted')
       write(9,45)
45     format(2x,' step   k1      k2       k3       k4       k5     ',
     & ' k6         k7        k8        Ptot       Eff           kcat',
     & '        Km         P1         P2         P3        P4       ',
     & '  J          S(I)       p1         p2         p3         p4 ',
     & '        Ktot        X')
C
        do 50 i=1,10000
C Random normal noise is different for each rate constant. No shift
C in Box-Muller trasform.
        call random_number(s1)
        call random_number(s2)
C
C        gaussrand=sqrt(-2*2.3025851*dlog10(s1))*cos(2*pi*s2)+2.0
        gaussrand1=sqrt(-2*2.3025851*dlog10(s1))*cos(2*pi*s2)
C
        call random_number(s1)
        call random_number(s2)
C
        gaussrand2=sqrt(-2*2.3025851*dlog10(s1))*cos(2*pi*s2)
C
        call random_number(s1)
        call random_number(s2)
C
        gaussrand3=sqrt(-2*2.3025851*dlog10(s1))*cos(2*pi*s2)
C
        call random_number(s1)
        call random_number(s2)
C
        gaussrand4=sqrt(-2*2.3025851*dlog10(s1))*cos(2*pi*s2)
C
        call random_number(s1)
        call random_number(s2)
C
        gaussrand5=sqrt(-2*2.3025851*dlog10(s1))*cos(2*pi*s2)
C
        call random_number(s1)
        call random_number(s2)
C
        gaussrand6=sqrt(-2*2.3025851*dlog10(s1))*sin(2*pi*s2)
C
        call random_number(s1)
        call random_number(s2)
C
        gaussrand7=sqrt(-2*2.3025851*dlog10(s1))*sin(2*pi*s2)
C
        call random_number(s1)
        call random_number(s2)
C
        gaussrand8=sqrt(-2*2.3025851*dlog10(s1))*sin(2*pi*s2)
C
C  If some gsussrand factor is not positive, corresponding rate constant
C  does not change from its observed value.
        if (gaussrand1.gt.0) then
       ckonst4a(i)=4000.0*gaussrand1
C
         k41=ckonst4a(i)
         else
            ckonst4a(i)=4000.0
            k41=ckonst4a(i)
         endif
C
        if (gaussrand2.gt.0) then
         k14=400000000.0*products*gaussrand2
         else
          k14=400000000.0*products
         endif
         keqk41=k41/k14
C
        if (gaussrand3.gt.0) then
       ckonst3a(i)=60000.0*gaussrand3
         k34=ckonst3a(i)
         else
            ckonst3a(i)=60000.0
            k34=ckonst3a(i)
         endif
C
        if (gaussrand4.gt.0) then
         k43=90000.0*gaussrand4
         else
          k43=90000.0
         endif
         keqk34=k34/k43
C
        if (gaussrand5.gt.0) then
       ckonst2a(i)=2000.0*gaussrand5
         k23=ckonst2a(i)
         else
            ckonst2a(i)=2000.0
            k23=ckonst2a(i)
         endif
C
        if (gaussrand6.gt.0) then
         k32=6000.0*gaussrand6
         else
          k32=6000.0
         endif
         keqk23=k23/k32
C
        if (gaussrand7.gt.0) then
       ckonst1a(i)=10000000.0*substrates*gaussrand7
         k12=ckonst1a(i)
         else
            ckonst1a(i)=10000000.0*substrates
            k12=ckonst1a(i)
         endif
C
        if (gaussrand8.gt.0) then
          k21=7000.0*gaussrand8
          else
           k21=7000.0
         endif
          keqk12=k12/k21
C
C
       kcat=(k23*k34*k41)/((k23+k32)*(k43+k41)+k23*k34+k34*k41)
C
       Ktot=keqk12*keqk23*keqk34*keqk41
C
       KMich=(k21*(k32*(k43+k41)+k34*k41)+k23*k34*k41)*substrates/
     &       (k12*((k23+k32)*(k43+k41)+k23*k34+k34*k41))
C
        ENZeff=kcat/KMich
C
         sigma=0.0
         sigmab=0.0
         sigmah=0.0
         sigmaq=0.0
         sigmap=0.0
C 4-th state probability added p=1,b=2,h=3,q=4
         entrops=0.0
	   enprodB1=0.0
	   enprodB2=0.0
	   enprodB3=0.0
       enprodB4=0.0
	   enprodT=0.0
C
           do 55 jj=1,4
         sprob(jj)=0.0
         entros(jj)=0.0
55       continue
C
         sigmap=k43*k32*k21+k21*k34*k41+k41*k32*k21+k23*k34*k41
         sigmab=k34*k41*k12+k14*k43*k32+k12*k43*k32+k32*k41*k12
         sigmah=k41*k12*k23+k21*k14*k43+k14*k43*k23+k12*k23*k43
         sigmaq=k32*k21*k14+k12*k23*k34+k14*k23*k34+k21*k14*k34
C
C
         sigma=sigmab+sigmah+sigmaq+sigmap
C
         sigmab=sigmab/sigma
         sigmah=sigmah/sigma
         sigmaq=sigmaq/sigma
         sigmap=sigmap/sigma
C
         sprob(1)=sigmab
         sprob(2)=sigmah
         sprob(3)=sigmaq
         sprob(4)=sigmap
C
       do 700 mmmm=1,4
          entros(mmmm)=-sprob(mmmm)*2.3*dlog10(sprob(mmmm))
          entrops=entrops+entros(mmmm)
700    continue
C
C
       xsec=thermale*2.3025851*dlog10((k12*k23*k34*k41)/
     & (k21*k32*k43*k14))
Cn all currents are without N (N=1)
C
        currB1=(k12*sigmap-k21*sigmab)
        currB2=(k23*sigmab-k32*sigmah)
        currB3=(k34*sigmah-k43*sigmaq)
        currB4=(k41*sigmaq-k14*sigmap)
C
          aX1=2.3025851*dlog10((k12*sigmap)/
     &   (k21*sigmab))
C
          aX2=2.3025851*dlog10((k23*sigmab)/
     &   (k32*sigmah))
C
          aX3=2.3025851*dlog10((k34*sigmah)/
     &   (k43*sigmaq))
C
          aX4=2.3025851*dlog10((k41*sigmaq)/
     &   (k14*sigmap))
C
          aX=aX1+aX2+aX3+aX4
C in RT units
C
        enprodB1=aX1*currB1
        enprodB2=aX2*currB2
        enprodB3=aX3*currB3
        enprodB4=aX4*currB4
C
        enprodT=enprodB1+enprodB2+enprodB3+enprodB4
C
C These enprod values are entropy production divided by the gas constant R
C Thus, units are in inverse seconds
C
       write(9,'(i6,8(f8.1,1x),3(f12.3,1x),1x,f9.6,1x,12(f10.5,1x))')
     &  i,k12,k21,k23,k32,k34,k43,k41,k14,enprodT,ENZeff,kcat,KMich,
     &  enprodB1,enprodB2,enprodB3,enprodB4,
     &  currB1,entrops,sigmap,sigmab,sigmah,sigmaq,keqk41,aX
C
 50    continue
C
       close(unit=9)
C
       stop
       end
C Author: Davor Juretic, year:2023, preprint:
C Computational Improvements of Enzyme Efficiency kcat/KM by Increasing Noise and Dissipation
C Submitted to the Entropy journal.
C Title: Theoretical Improvements in Enzyme Efficiency Associated with Noisy Rate Constants and Increased Dissipation
C This source code produce S7TPI-allrand-ki.dat parameters for random changes called 8 times for
C 8 rate constants. We then used the columns enprodT (named Ptot) and ENZeff (named Eff)
C to create figure 7 from the main text.
C The run time should be around 2.5 sec.
C
